'use client'
import useConversationsStore from "@/feature/messenger/store/chat_store/useConversationsStore";
import { Button, Chip, Dropdown, DropdownItem, DropdownMenu, DropdownSection, DropdownTrigger, Tooltip, useDisclosure } from "@nextui-org/react";
import SearchChat from "./SearchChat";
import { useState, useEffect } from "react";
import { Info, MoreVertical, Tag } from "react-feather";
import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import { getNameBySocial } from "@/feature/messenger/utils/TransFormName";
import { useTranslation } from "@/src/hooks/useTranslation";
import { IoMdArrowBack } from "react-icons/io";
import truncateText from "@/feature/messenger/utils/TruncateText";
import useTagsStore from "@/feature/messenger/store/useTagsStore";
import TagsModal from "@/feature/messenger/components/modals/TagsModal";
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import { ToastNotify } from "@/src/components/ToastNotify";
import useRigthSidebarStore from "@/feature/messenger/store/useRigthSidebarStore";

export default function HeaderChat() {

    const selectedConversation = useConversationsStore(state => state.selectedConversation);
    const resetSelectedConversation = useConversationsStore(state => state.actions.resetSelectedConversation);

    const nameUser = getNameBySocial(selectedConversation.nombre, selectedConversation.sesion, selectedConversation.rsocial);
    const [search, setSearch] = useState(false);
    const handleOpenFileShareConversation = useHandleConversationStore((state) => state.actions.handleOpenFileShareConversation);
    const { trans } = useTranslation();

    const { fetchTags, handleOpenTagsModal, error } = useTagsStore();
    const { handleOpenRigthSidebar } = useRigthSidebarStore();

    const id_chatbot = useConfigChatStore(state => state.idChatbot);
    const handleOpenTags = async () => {
        await  fetchTags(selectedConversation.sesion, Number(id_chatbot));
        if (error) {
            ToastNotify('warning', trans('modal_conversations_tags_empty_title'));
        }
    };
    
    const [windowWidth, setWindowWidth] = useState(0);

    useEffect(() => {
        setWindowWidth(window.innerWidth);
        const handleResize = () => {
            setWindowWidth(window.innerWidth);
        };
        window.addEventListener('resize', handleResize);
        return () => {
            window.removeEventListener('resize', handleResize);
        };
    }, []);

    return (
        <header className="w-full md:p-2 h-24 flex justify-between items-center border-b-1 border-gray-100 dark:bg-gray-700">
            {/* Logo */}
            <div className={`${search ? "hidden" : "visible"} w-full flex justify-start items-center`}>
                <div className="flex md:hidden justify-center items-center">
                    <span className="cursor-pointer pl-1" onClick={() => resetSelectedConversation()}>
                        <IoMdArrowBack className="size-7 text-indigo-500 dark:text-white" />
                    </span>
                </div>
                <div className="flex justify-center items-center md:gap-3">
                    <div className="md:p-2">
                        <div className="size-12 md:size-14 lg:size-16 rounded-full m-1 min-w-12 sm:min-w-12 md:min-w-14 lg:min-w-16"
                            style={{
                                backgroundImage: `url('${process.env.ASSET_PREFIX || ''}/chat/assets/images/contact/${selectedConversation.rsocial}.png')`,
                                backgroundSize: "cover",
                                backgroundPosition: "center",
                                display: "block",
                            }}
                        >
                        </div>
                    </div>
                    <div className="flex flex-col justify-center items-start gap-1 w-auto">
                        <p className="text-sm md:text-base font-semibold">
                            {typeof window !== 'undefined' && windowWidth < 768 ? truncateText(nameUser, 15) : nameUser}
                        </p>
                        <Chip color="success" className="text-xs h-6 text-white">
                            {trans('header_content_chat_online_title')}
                        </Chip>
                    </div>
                </div>
            </div>

            {/* Search Chat */}
            <div className={`flex flex-row-reverse justify-end items-center ${search ? "w-full" : ""}`}>
                <Dropdown placement="top">
                    <Tooltip
                        placement="right"
                        content={trans('header_options_dropdown_content_chat_title')}
                        color="default"
                    >
                        <div>
                            <DropdownTrigger>
                                <MoreVertical className='text-indigo-500 dark:text-white' size={30} />
                            </DropdownTrigger>
                        </div>
                    </Tooltip>
                    <DropdownMenu aria-label="Profile Actions" variant="faded" className="p-2">
                        <DropdownSection title={trans('header_options_dropdown_content_chat_title')}>
                            <DropdownItem key="reenviar" className="text-lg" textValue="reenviar" onClick={() => handleOpenFileShareConversation()}>
                                <p className="text-base">{trans('header_options_dropdown_view_resources_title')}</p>
                            </DropdownItem>
                        </DropdownSection>
                    </DropdownMenu>
                </Dropdown>

                {/* Nuevo botón para abrir la sidebar */}
                {/*<Tooltip
                    placement="right"
                    content={trans('header_options_dropdown_content_chat_title')}
                    color="default"
                >
                    <Button
                        isIconOnly
                        color="default"
                        aria-label="Tags"
                        className="bg-transparent p-0"
                        onClick={handleOpenRigthSidebar}
                    >
                        <Info className="text-indigo-500 dark:text-white" size={20} />
                    </Button>
                </Tooltip>*/}

                {/* Nuevo botón para abrir los tags */}
                <Tooltip
                    placement="right"
                    content={trans('modal_conversations_tags_title')}
                    color="default"
                >
                    <Button
                        isIconOnly
                        color="default"
                        aria-label="Tags"
                        className="bg-transparent p-0"
                        onClick={handleOpenTags}
                    >
                        <Tag className="text-indigo-500 dark:text-white" size={20} />
                    </Button>
                </Tooltip>

                <SearchChat search={search} setSearch={setSearch} />
            </div>

            {/* Modal para mostrar los tags */}
            <TagsModal />
        </header>
    );
}